#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
const tslib_1 = require("tslib");
const commander_1 = require("commander");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const load_yaml_1 = require("../../utils/load-yaml");
const logging_1 = require("../../utils/logging");
const fs_1 = require("fs");
const path_1 = require("path");
// import { redisHandler } from "../../utils/redis"
const question_1 = require("./question");
const publishOutfile_1 = require("../commons/publishOutfile");
exports.logger = logging_1.getLogger();
const cfgobj = load_yaml_1.loadYaml("config/main.cfg.yaml");
commander_1.program
    .option("-p, --pro <string>", "项目名称")
    .option("-m, --model <string>", "模块名称")
    .option("-s, --subModel <string>", "子模块名称")
    .option("-f, --fileName <string>", "文件名")
    .option("-r, --roomName <string>", "房间名");
commander_1.program.parse(process.argv);
const opts = commander_1.program.opts();
if (!opts.roomName) {
    throw new TypeError("roomName is must...");
}
function mainProcess(opts) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let question;
        const { pro, model, subModel } = opts;
        if (pro && model && subModel) {
            question = {
                projectName: pro,
                modelName: model,
                subModelName: subModel
            };
        }
        else {
            // 询问项目名/模块名和子模块名
            const q = yield question_1.doQuestion();
            question = q;
        }
        if (question == null) {
            exports.logger.error("question is not complate...!");
            return;
        }
        // 询问文件名
        let fName;
        if (opts.fileName) {
            fName = {
                fileName: opts.fileName
            };
        }
        else {
            fName = yield inquirer_1.default.prompt({
                name: "fileName",
                type: "input",
                message: "文件名"
            });
        }
        // 创建文件
        const fileName = path_1.resolve(cfgobj.question.cached_dir, question.projectName, question.modelName, question.subModelName, fName.fileName + ".yaml");
        // const cachedName = resolve(cfgobj.question.struct_cached_dir, question.projectName, question.modelName, question.subModelName, fName.fileName + ".json")
        if (!fs_1.existsSync(fileName)) {
            const theDir = path_1.dirname(fileName);
            // 如果目录不存在需要先创建目录
            if (!fs_1.existsSync(theDir)) {
                fs_1.mkdirSync(theDir, { recursive: true }); // 递归创建目录
            }
            fs_1.writeFile(fileName, "", err => {
                if (err) {
                    exports.logger.error(err);
                }
                else {
                    exports.logger.info("创建文件成功...!");
                }
            });
        } // end if
        // 将本地配置缓存推送到配置端
        const cachedPth = path_1.resolve("node_modules", question.projectName, "caches", question.modelName, question.subModelName, cfgobj.model.cache_file_name);
        const metasPth = path_1.resolve("node_modules", question.projectName, "metas", question.modelName, question.subModelName, cfgobj.model.metas_file_name);
        const metascriptPth = path_1.resolve("node_modules", question.projectName, "src", question.modelName, question.subModelName, cfgobj.model.metascript_file_name);
        // const targetCachedPth = resolve(cfgobj.question.struct_cached_dir, question.projectName, question.modelName, question.subModelName, fName.fileName + ".json")
        if (fs_1.existsSync(metascriptPth)) {
            const { getMetaInfo } = require(metascriptPth);
            const { title, treeCode, treeData } = getMetaInfo(question.projectName, question.modelName, question.subModelName, fName.fileName);
            exports.logger.info(`title: ${title}; `);
            if (treeData) {
                pushCachedStruct(title, JSON.stringify({ code: treeCode, data: treeData }), opts.roomName);
            }
            else {
                pushCached(title, treeCode, opts.roomName);
            }
            exports.logger.info("emit-script meta success");
        }
        // else if (existsSync(targetCachedPth)) { // 存在目标文件的缓存
        //   logger.info("use file cached...")
        //   pushCachedStruct(question.modelName + "-" + question.subModelName + ":" + fName.fileName
        //     , readFileSync(targetCachedPth, { encoding: "utf-8" }))
        //   logger.info("emit-code success")
        // }
        else if (fs_1.existsSync(cachedPth)) { // 存在针对模块的缓存文件
            exports.logger.info("use model cached....");
            // redisHandler(clt => {
            //   // 设置配置文件内容到redis
            //   clt.hset("config-cached-struct", "title", question.modelName + "-" + question.subModelName + ":" + fName.fileName
            //     , "treeCode", readFileSync(cachedPth, { encoding: "utf-8" }), num => {
            //       logger.info(`publish ${cfgobj.redis.channel} code-struct-cached...`)
            //       clt.publish(cfgobj.redis.channel, "code-struct-cached") // 推送代码结构
            //       clt.quit()
            //     })
            // })
            exports.logger.info("emit-code success");
        }
        else if (fs_1.existsSync(metasPth)) { // 否则使用元配置文件
            exports.logger.info("use meta...");
            // redisHandler(clt => {
            //   const titlePth = resolve("node_modules", question.projectName, "metas", question.modelName, question.subModelName, cfgobj.model.title_file_name)
            //   // 设置配置文件内容到redis
            //   clt.hset("config-struct", "title", readFileSync(titlePth, { encoding: "utf-8" })
            //     , "treeCode", readFileSync(metasPth, { encoding: "utf-8" }), num => {
            //       logger.info(`publish ${cfgobj.redis.channel} code-struct...`)
            //       clt.publish(cfgobj.redis.channel, "code-struct") // 推送代码结构
            //       clt.quit()
            //     })
            // })
            exports.logger.info("emit-code success");
        }
        else {
            throw new TypeError("没有对应的缓存文件");
        }
        // 关联配置端到输出文件
        // publishOutfile(fileName, cachedName)
        publishOutfile_1.publishOutfile(fileName, "", opts.roomName);
        const outfilesCached = {
            outfile: fileName,
        };
        fs_1.writeFile('.cached_outfiles', JSON.stringify(outfilesCached), (err) => {
            if (err) {
                exports.logger.error("cached_outfiles write fail...");
            }
            else {
                exports.logger.info("cached_outfiles write success...");
            }
        });
    });
}
mainProcess(opts);
function pushCachedStruct(title, treeCode, room) {
    // redisHandler(clt => {
    //   // 设置配置文件内容到redis
    //   clt.hset("config-cached-struct", "title", title,
    //     "treeCode", treeCode, num => {
    //       logger.info(`publish ${cfgobj.redis.channel} code-struct-cached...`)
    //       clt.publish(cfgobj.redis.channel, "code-struct-cached-"+room) // 推送代码结构
    //       clt.quit()
    //     })
    // })
}
function pushCached(title, treeCode, room) {
    // redisHandler(clt => {
    //   // 设置配置文件内容到redis
    //   clt.hset("config-struct", "title", title,
    //     "treeCode", treeCode, num => {
    //       logger.info(`publish ${cfgobj.redis.channel} code-struct...`)
    //       clt.publish(cfgobj.redis.channel, "code-struct-" + room) // 推送代码结构
    //       clt.quit()
    //     })
    // })
}
