"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.doQuestion = void 0;
const tslib_1 = require("tslib");
const load_yaml_1 = require("../../utils/load-yaml");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const logging_1 = require("../../utils/logging");
const fs_1 = require("fs");
const path_1 = require("path");
const logger = logging_1.getLogger();
const questionPath = 'config/watch/question.yaml';
const prefixModel = "mill-template-";
const questionObj = load_yaml_1.loadYaml(questionPath);
const [project, model, subModel] = questionObj;
class QuestionError extends TypeError {
}
/**
 * 交互询问项目名称
 * @param answer 问题
 * @returns 项目名称
 */
function getProjectName(answer) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const basePath = path_1.resolve("node_modules");
        if (!fs_1.existsSync(basePath)) {
            throw new QuestionError("the dir node_modules is not exists...");
        }
        const files = fs_1.readdirSync(basePath).filter(el => el.startsWith(prefixModel));
        if (!files.length) {
            throw new QuestionError("not installed mill-templates, plase install its...");
        }
        answer.choices = files.map(el => {
            return {
                name: el,
                value: el
            };
        });
        const projectName = yield inquirer_1.default.prompt(answer);
        // TODO choices 需要从客户目录中找mill-templates
        // const choices = (answer as any).choices
        // console.log(choices)
        return projectName.project;
    });
}
/**
 * 交互询问模块名称
 * @param projectName 项目名称
 * @param answer 问题
 * @returns
 */
function getModelName(projectName, answer) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const basePath = path_1.resolve("node_modules", projectName, "src");
        if (!fs_1.existsSync(basePath)) {
            throw new QuestionError("the module has not src dir...");
        }
        const files = fs_1.readdirSync(basePath);
        answer.choices = files.map(el => {
            return {
                name: el,
                value: el
            };
        });
        const modelName = yield inquirer_1.default.prompt(answer);
        // TODO 从指定的projectName找到model，供用户选择
        // throw new QuestionError("question ...");
        return modelName.model;
    });
}
/**
 *
 * @param projectName 项目名称
 * @param modelName 模块名称
 * @param answer
 * @returns
 */
function getSubModelName(projectName, modelName, answer) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        // TODO 从子模块名找到脚本供用户选择
        const basePath = path_1.resolve("node_modules", projectName, "src", modelName);
        if (!fs_1.existsSync(basePath)) {
            throw new QuestionError("the module has not sub module...");
        }
        const files = fs_1.readdirSync(basePath);
        answer.choices = files.map(el => {
            return {
                name: el,
                value: el
            };
        });
        const subModelName = yield inquirer_1.default.prompt(answer);
        return subModelName.sub_model;
    });
}
function doQuestion() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const projectName = yield getProjectName(project);
            const modelName = yield getModelName(projectName, model);
            const subModelName = yield getSubModelName(projectName, modelName, subModel);
            const question = {
                projectName, modelName, subModelName
            };
            // console.log(question)
            return question;
        }
        catch (error) {
            logger.error(error.message);
        }
        return null;
    });
}
exports.doQuestion = doQuestion;
