"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const socket_client_1 = require("../../../utils/socket-client");
const commander_1 = require("commander");
const logging_1 = require("../../../utils/logging");
const fs_1 = require("fs");
const yaml_1 = require("yaml");
const path_1 = require("path");
const handleMessage_1 = require("./handleMessage");
const shelljs_1 = tslib_1.__importDefault(require("shelljs"));
const logger = logging_1.getLogger();
logger.info("start subscribe...");
commander_1.program
    .option("-n, --roomName <string>", "聊天室的名称");
commander_1.program.parse(process.argv);
const opts = commander_1.program.opts();
if (!opts.roomName) {
    throw new TypeError("房间名必须提供");
}
const msgHandler = new handleMessage_1.MessageHandler(logger, socket_client_1.socket);
/**
 * 连接成功
 */
socket_client_1.socket.on("connect", () => {
    socket_client_1.socket.emit("registry", opts.roomName);
    logger.info("connected socket service！");
});
/**
 * 获取代码，写出到文件
 */
socket_client_1.socket.on('eating', msg => {
    try {
        logger.info(`触发 eating 事件...`);
        // 解析参数
        const { _id, project, generator, generatorModel, subModel, fileName, data } = msg;
        if (data && generator && generatorModel && subModel && fileName) {
            // 组成路径
            const projectName = `mill-template-${generator}`;
            const cachedPath = path_1.resolve(".config_cached", projectName, generatorModel, subModel, fileName + ".yaml");
            const cachedDir = path_1.dirname(cachedPath);
            // 确保目录存在
            if (!fs_1.existsSync(cachedDir)) {
                fs_1.mkdirSync(cachedDir, { recursive: true });
            }
            // 写出文件
            fs_1.writeFile(cachedPath, yaml_1.stringify(data), { encoding: 'utf-8' }, (err) => {
                if (err) {
                    throw err;
                }
                try {
                    // 执行脚本
                    const scriptFile = path_1.resolve("node_modules", projectName, "src", generatorModel, subModel);
                    // 脚本不存在
                    if (!fs_1.existsSync(scriptFile)) {
                        logger.warn(scriptFile);
                        msgHandler.message("script is not exists!", handleMessage_1.MsgStatus.WARN);
                        return;
                    }
                    // 导入脚本
                    const { process } = require(scriptFile);
                    // 执行脚本
                    process(cachedPath, data, (err) => {
                        if (err) {
                            throw err;
                        }
                        else {
                            msgHandler.message("脚本执行成功!", handleMessage_1.MsgStatus.SUCCESS);
                        }
                    });
                }
                catch (error) {
                    msgHandler.message(error.message, handleMessage_1.MsgStatus.ERROR);
                }
            });
        }
    }
    catch (error) {
        msgHandler.message(error.message, handleMessage_1.MsgStatus.ERROR);
    }
});
socket_client_1.socket.on('command', msg => {
    try {
        const result = shelljs_1.default.exec(msg);
        msgHandler.message(result, handleMessage_1.MsgStatus.SUCCESS);
    }
    catch (error) {
        msgHandler.message(error.message, handleMessage_1.MsgStatus.ERROR);
    }
});
// 关闭连接到时候调用
socket_client_1.socket.on("unconnect", () => {
    logger.info("unconnect...");
});
