#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const load_yaml_1 = require("../../utils/load-yaml");
const logging_1 = require("../../utils/logging");
const fs_1 = require("fs");
const chokidar_1 = require("chokidar");
const path_1 = require("path");
const logger = logging_1.getLogger();
const cfgobj = load_yaml_1.loadYaml("config/main.cfg.yaml");
function mainProcess() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const baseDir = cfgobj.question.cached_dir;
        if (!fs_1.existsSync(baseDir)) {
            fs_1.mkdirSync(baseDir);
        }
        const w = chokidar_1.watch(baseDir);
        w.on("change", (pth, stats) => {
            logger.info(pth + " changed!");
            if (!stats) {
                logger.error("stats is null !");
            }
            else {
                logger.info(stats.ctime);
            }
            const [_, projectName, modelName, subModelName, fileName] = pth.split(path_1.sep);
            const scriptFile = path_1.resolve("node_modules", projectName, "src", modelName, subModelName);
            const { process } = require(scriptFile);
            process(pth, (err) => {
                if (err) {
                    logger.error(err.message);
                }
                else {
                    logger.info("process success!");
                }
            });
        });
        logger.info("start watch " + baseDir + "!");
    });
}
mainProcess();
