import { socket } from "../../../utils/socket-client"
import { program } from "commander"
import { getLogger } from "../../../utils/logging"
import { writeFile, existsSync, mkdirSync, writeFileSync } from "fs"
import { stringify, parse } from "yaml"
import { dirname, resolve } from "path"
import { MessageHandler, MsgStatus } from "./handleMessage"

import shelljs from "shelljs"
const logger = getLogger()
logger.info("start subscribe...")

program
  .option("-n, --roomName <string>", "聊天室的名称")
program.parse(process.argv)
const opts = program.opts()

if (!opts.roomName) {
  throw new TypeError("房间名必须提供")
}


const msgHandler = new MessageHandler(logger, socket)
/**
 * 连接成功
 */
socket.on("connect", () => {
  socket.emit("registry", opts.roomName)
  logger.info("connected socket service！")
})

/**
 * 获取代码，写出到文件
 */
socket.on('eating', msg => {
  try {


    logger.info(`触发 eating 事件...`)

    // 解析参数
    const { _id, project, generator, generatorModel, subModel, fileName, data } = msg;
    if (data && generator && generatorModel && subModel && fileName) {

      // 组成路径
      const projectName = `mill-template-${generator}`
      const cachedPath = resolve(".config_cached", projectName, generatorModel, subModel, fileName + ".yaml")
      const cachedDir = dirname(cachedPath)

      // 确保目录存在
      if (!existsSync(cachedDir)) {
        mkdirSync(cachedDir, { recursive: true })
      }

      // 写出文件
      writeFile(cachedPath
        , stringify(data)
        , { encoding: 'utf-8' }
        , (err) => {
          if (err) {
            throw err
          }

          try {
            // 执行脚本
            const scriptFile = resolve("node_modules", projectName, "src", generatorModel, subModel)

            // 脚本不存在
            if (!existsSync(scriptFile)) {
              logger.warn(scriptFile)
              msgHandler.message("script is not exists!", MsgStatus.WARN)
              return
            }

            // 导入脚本
            const { process } = require(scriptFile)

            // 执行脚本
            process(cachedPath, data, (err) => {
              if (err) {
                throw err
              } else {
                msgHandler.message("脚本执行成功!", MsgStatus.SUCCESS)
              }
            });
          } catch (error) {
            msgHandler.message(error.message, MsgStatus.ERROR)
          }

        })
    }

  } catch (error) {
    msgHandler.message(error.message, MsgStatus.ERROR)
  }

});

socket.on('command', msg => {
  try {
    const result = shelljs.exec(msg)
    msgHandler.message(result, MsgStatus.SUCCESS)
  } catch (error) {
    msgHandler.message(error.message, MsgStatus.ERROR)
  }
})

// 关闭连接到时候调用
socket.on("unconnect", () => {
  logger.info("unconnect...")
})