#!/usr/bin/env node


import { loadYaml } from "../../utils/load-yaml"
import { getLogger } from "../../utils/logging"
import { existsSync, mkdirSync, readdir, readFile, writeFile } from "fs"
import { watch } from "chokidar"
import { resolve,  sep } from "path"

const logger = getLogger()
const cfgobj = loadYaml("config/main.cfg.yaml")

async function mainProcess() {

  const baseDir = cfgobj.question.cached_dir;
  if (!existsSync(baseDir)) {
    mkdirSync(baseDir)
  }
  const w = watch(baseDir)

  w.on("change", (pth, stats) => {
    logger.info(pth + " changed!")
    if (!stats) {
      logger.error("stats is null !")
    }else{
      logger.info(stats.ctime)
    }
    const [_, projectName, modelName, subModelName, fileName] = pth.split(sep)
    const scriptFile = resolve("node_modules", projectName, "src", modelName, subModelName)
    const { process } = require(scriptFile)
    process(pth,(err)=>{
      if(err){
        logger.error(err.message)
      }else{
        logger.info("process success!")
      }
    });

  })

  logger.info("start watch " + baseDir + "!")

}
mainProcess();


