import { createClient, RedisClient } from "redis"
import { getLogger } from "./logging"
import { loadYaml } from "./load-yaml"
const cfgobj = loadYaml("config/main.cfg.yaml")

const logger = getLogger();

function getRedisClient() {
  const redisClient = createClient({
    host: cfgobj.redis.host,
    port: cfgobj.redis.port,
    password: cfgobj.redis.password
  })
  return redisClient
}


/**
 *
 * redis的处理函数
 * @param fn 回调函数
 */
function redisHandler(fn: (clt: RedisClient) => void) {
  const client = getRedisClient()
  try {
    fn(client)
  } catch (err) {
    logger.error(err)
  }
}

function publish(channel: string, message: string) {
  const client = getRedisClient()
  client.publish(channel, message)
  client.quit()
}


export {
  // getRedisClient, redisHandler, publish
}